@@ -61,14 +61,16 @@ class TrellisImageTo3DPipeline(Pipeline):
             path (str): The path to the model. Can be either local path or a Hugging Face repository.
         """
 
-        shape_pipeline = Tri3DDiTFlowMatchingPipeline.from_pretrained(str(path))
-
+        shape_pipeline = Tri3DDiTFlowMatchingPipeline.from_single_file(
+            ckpt_path=os.path.join(path, "shape/model.fp16.ckpt"),
+            config_path=os.path.join(path, "shape/config.yaml"))
+        
         current_dir = Path(__file__).resolve().parent
         cus_pip = current_dir.parent / "paint3d" / "tripaintpbr"
         
         # paint model
         max_num_view = 6
-        resolution = 768
+        resolution = 512
         conf = Tri3DPaintConfig(max_num_view, resolution)
         conf.realesrgan_ckpt_path = os.path.join(path, "ckpt/RealESRGAN_x4plus.pth")
         conf.multiview_cfg_path = os.path.join(path, "texture/paint.yaml")
