@@ -31,18 +31,18 @@ def to_glb(
     with open(tmp_glb, 'rb') as f:
         glb_data = f.read()
     
-    # frames
-    frames = get_image(tmp_glb)
+    # # frames
+    # frames = get_image(tmp_glb)
 
-    # 用完删除（可选）
-    if os.path.exists(tmp_glb):
-        os.remove(tmp_glb)
+    # # 用完删除（可选）
+    # if os.path.exists(tmp_glb):
+    #     os.remove(tmp_glb)
     
-    for name in ["textured_mesh.mtl", "textured_mesh.jpg", "textured_mesh.obj"]:
-        if os.path.exists(name):
-            os.remove(name)
+    # for name in ["textured_mesh.mtl", "textured_mesh.jpg", "textured_mesh.obj"]:
+    #     if os.path.exists(name):
+    #         os.remove(name)
     
-    return [glb_data, frames, 0]
+    return [glb_data, 0, 0]
 
 def to_thumbnail(gaussian):
 
